summaryrefslogtreecommitdiffstats
path: root/kresources/exchange/resourceexchange.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kresources/exchange/resourceexchange.cpp')
-rw-r--r--kresources/exchange/resourceexchange.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/kresources/exchange/resourceexchange.cpp b/kresources/exchange/resourceexchange.cpp
index ec203b9cd..234907fcb 100644
--- a/kresources/exchange/resourceexchange.cpp
+++ b/kresources/exchange/resourceexchange.cpp
@@ -233,7 +233,7 @@ void ResourceExchange::slotMonitorNotify( const TQValueList<long>& IDs, const TQ
* 3. Event modified that we have in cache
* 4. Something else happened that isn't relevant to us
* Update cache, then notify whoever's watching us
* We may be able to find (1) and (3) by looking at the
* DAV:getlastmodified property
* (2) is trickier: we might have to resort to checking
* all uids in the cache
@@ -298,7 +298,7 @@ void ResourceExchange::changeIncidence( Incidence *incidence )
kdDebug() << "ResourceExchange::changeIncidence(): "
<< incidence->summary() << endl;
- if ( mChangedIncidences.find( incidence ) == mChangedIncidences.end() ) {
+ if ( mChangedIncidences.tqfind( incidence ) == mChangedIncidences.end() ) {
mChangedIncidences.append( incidence );
}
}
@@ -505,7 +505,7 @@ Event::List ResourceExchange::rawEventsForDate( const TQDate &qd,
// are really new.
Event::List eventsAfter = mCache->rawEvents();
for ( it = eventsAfter.begin(); it != eventsAfter.end(); ++it ) {
- if ( eventsBefore.find( *it ) == eventsBefore.end() ) {
+ if ( eventsBefore.tqfind( *it ) == eventsBefore.end() ) {
// it's a new event downloaded by downloadSynchronous -> install observer
(*it)->registerObserver( this );
}
@@ -233,7 +233,7 @@ void ResourceExchange::slotMonitorNotify( const TQValueList<long>& IDs, const TQ
* 4. Something else happened that isn't relevant to us
* Update cache, then notify whoever's watching us
- * We may be able to find (1) and (3) by looking at the
+ * We may be able to tqfind (1) and (3) by looking at the
* DAV:getlastmodified property
* (2) is trickier: we might have to resort to checking